@@ -79,6 +79,10 @@ class VerilatedVar;
 class VerilatedVarNameMap;
 class VerilatedVcd;
 class VerilatedVcdC;
+class VerilatedLxt2;
+class VerilatedLxt2C;
+class VerilatedFst;
+class VerilatedFstC;
 
 enum VerilatedVarType {
     VLVT_UNKNOWN=0,
@@ -92,15 +96,16 @@ enum VerilatedVarType {
 };
 
 enum VerilatedVarFlags {
-    VLVD_IN=1,		// == vpiInput
-    VLVD_OUT=2,		// == vpiOutput
-    VLVD_INOUT=3,	// == vpiInOut
-    VLVD_NODIR=5,	// == vpiNoDirection
-    VLVF_MASK_DIR=7,	// Bit mask for above directions
+    VLVD_0 = 0,         // None
+    VLVD_IN = 1,	// == vpiInput
+    VLVD_OUT = 2,	// == vpiOutput
+    VLVD_INOUT = 3,	// == vpiInOut
+    VLVD_NODIR = 5,	// == vpiNoDirection
+    VLVF_MASK_DIR = 7,	// Bit mask for above directions
     // Flags
-    VLVF_PUB_RD=(1<<8),	// Public readable
-    VLVF_PUB_RW=(1<<9),  // Public writable
-    VLVF_DPI_CLAY=(1<<10)  // DPI compatible C standard layout
+    VLVF_PUB_RD = (1<<8),  // Public readable
+    VLVF_PUB_RW = (1<<9),  // Public writable
+    VLVF_DPI_CLAY = (1<<10)  // DPI compatible C standard layout
 };
 
 //=========================================================================
@@ -120,6 +125,7 @@ class VL_CAPABILITY("mutex") VerilatedMutex {
   public:
     VerilatedMutex() {}
     ~VerilatedMutex() {}
+    const VerilatedMutex& operator!() const { return *this; }  // For -fthread_safety
     /// Acquire/lock mutex
     void lock() VL_ACQUIRE() {
         // Try to acquire the lock by spinning.  If the wait is short,
@@ -344,9 +350,21 @@ class Verilated {
         ~Serialized() {}
     } s_s;
 
+    static struct NonSerialized {  // Non-serialized information
+        // These are reloaded from on command-line settings, so do not need to persist
+        // Fast path
+        vluint64_t s_profThreadsStart;  ///< +prof+threads starting time
+        vluint32_t s_profThreadsWindow;  ///< +prof+threads window size
+        // Slow path
+        const char* s_profThreadsFilenamep;  ///< +prof+threads filename
+        NonSerialized();
+        ~NonSerialized();
+    } s_ns;
+
     // no need to be save-restored (serialized) the
     // assumption is that the restore is allowed to pass different arguments
     static struct CommandArgValues {
+        VerilatedMutex m_argMutex;  ///< Mutex for s_args members, when VL_THREADED
 	int          argc;
 	const char** argv;
         CommandArgValues() : argc(0), argv(NULL) {}
@@ -408,6 +426,14 @@ public:
     /// Enable/disable vpi fatal
     static void fatalOnVpiError(bool flag) VL_MT_SAFE;
     static bool fatalOnVpiError() VL_MT_SAFE { return s_s.s_fatalOnVpiError; }
+    /// --prof-threads related settings
+    static void profThreadsStart(vluint64_t flag) VL_MT_SAFE;
+    static vluint64_t profThreadsStart() VL_MT_SAFE { return s_ns.s_profThreadsStart; }
+    static void profThreadsWindow(vluint64_t flag) VL_MT_SAFE;
+    static vluint32_t profThreadsWindow() VL_MT_SAFE { return s_ns.s_profThreadsWindow; }
+    static void profThreadsFilenamep(const char* flagp) VL_MT_SAFE;
+    static const char* profThreadsFilenamep() VL_MT_SAFE { return s_ns.s_profThreadsFilenamep; }
+
     /// Flush callback for VCD waves
     static void flushCb(VerilatedVoidCb cb) VL_MT_SAFE;
     static void flushCall() VL_MT_SAFE;
@@ -425,6 +451,9 @@ public:
     static const char* productName() VL_PURE { return VERILATOR_PRODUCT; }
     static const char* productVersion() VL_PURE { return VERILATOR_VERSION; }
 
+    /// Convenience OS utilities
+    static void mkdir(const char* dirname) VL_MT_UNSAFE;
+
     /// When multithreaded, quiesce the model to prepare for trace/saves/coverage
     /// This may only be called when no locks are held.
     static void quiesce() VL_MT_SAFE;
@@ -499,31 +528,31 @@ private:
 /// User code may wish to replace this function, to do so, define VL_USER_FINISH.
 /// This code does not have to be thread safe.
 /// Verilator internal code must call VL_FINISH_MT instead, which eventually calls this.
-extern void vl_finish (const char* filename, int linenum, const char* hier);
+extern void vl_finish(const char* filename, int linenum, const char* hier);
 
 /// Routine to call for $stop
 /// User code may wish to replace this function, to do so, define VL_USER_STOP.
 /// This code does not have to be thread safe.
 /// Verilator internal code must call VL_FINISH_MT instead, which eventually calls this.
-extern void vl_stop   (const char* filename, int linenum, const char* hier);
+extern void vl_stop(const char* filename, int linenum, const char* hier);
 
 /// Routine to call for a couple of fatal messages
 /// User code may wish to replace this function, to do so, define VL_USER_FATAL.
 /// This code does not have to be thread safe.
 /// Verilator internal code must call VL_FINISH_MT instead, which eventually calls this.
-extern void vl_fatal  (const char* filename, int linenum, const char* hier,
-		       const char* msg);
+extern void vl_fatal(const char* filename, int linenum, const char* hier,
+                     const char* msg);
 
 //=========================================================================
 // Extern functions -- Slow path
 
 /// Multithread safe wrapper for calls to $finish
-extern void VL_FINISH_MT (const char* filename, int linenum, const char* hier) VL_MT_SAFE;
+extern void VL_FINISH_MT(const char* filename, int linenum, const char* hier) VL_MT_SAFE;
 /// Multithread safe wrapper for calls to $stop
-extern void VL_STOP_MT   (const char* filename, int linenum, const char* hier) VL_MT_SAFE;
+extern void VL_STOP_MT(const char* filename, int linenum, const char* hier) VL_MT_SAFE;
 /// Multithread safe wrapper to call for a couple of fatal messages
-extern void VL_FATAL_MT  (const char* filename, int linenum, const char* hier,
-			  const char* msg) VL_MT_SAFE;
+extern void VL_FATAL_MT(const char* filename, int linenum, const char* hier,
+                        const char* msg) VL_MT_SAFE;
 
 /// Print a string, multithread safe. Eventually VL_PRINTF will get called.
 #ifdef VL_THREADED
